==> pochy-0.1.8-src.tar.gz: pochy-0.1.8-src/lib.h <==
//#include "liststackstruct.h"

void g_log(CString path, CString log);
BOOL g_rm_recursive(CString path);
BOOL g_cstring2file(/*CString& buf*/LPCTSTR buf, LPCTSTR filename);
BOOL g_file2cstring(LPCTSTR filename,CString& buf);
BOOL g_fcreate(LPCTSTR path);
BOOL g_connect_process(CStringArray &comline, CString &out1, CString &out2);
//int g_get_icon_index(const CString& csFileName);
// CStringesCStringArrayɊi[
void g_cstr2cstra(CString& cstr, CStringArray& cstra, LPCTSTR sep);
void g_cstr2cstra_ex(CString& cstr, CStringArray& cstra, LPCTSTR sep);
// CStringArrayɊesi[̂CStringɏo
void g_cstra2cstr(CStringArray& cstra, CString& cstr, int size);
// eLXgt@C̊esCStringArrayɓǂݍ
BOOL g_file2cstra(LPCTSTR path, CStringArray &cstra);
// CStringArrayɊesi[ꂽeLXgt@C֏o
BOOL g_cstra2file(LPCTSTR path, CStringArray &cstra);
// t@C̑傫Ԃ
long g_getfs(LPCTSTR path);
// t@CԍƂČƂA(num)ȏł܂݂Ȃŏ̔ԍԂ֐
int g_get_min_num(CString path);
// CStringArraystartsends܂ł擾
void g_cstra_getpart(CStringArray &org, CStringArray &dst, int start, int end);
// CStringArrayɊi[ĂCString̑TCY擾
int g_cstra_getsize(CStringArray& cstra);
// t@CtH_邩ȂmF
BOOL g_is_there(LPCTSTR path);
// 啶̊֌WȂCStringׁAvTRUEԂ
BOOL g_cstr_compare(LPCTSTR c, LPCTSTR d);
// <>̒̕Ԃ֐
CString g_ma(CString& to);
CString g_getfield(CString& body, LPCTSTR name);
CString g_gen_msgid(CString from);
void g_cstr_chop(CString &buf);
CString g_cstr_chop2(CString buf);
int g_cstr_rvs_find(CString org, LPCTSTR key, int start);
// e|[t@C쐬Ãt@Cւ̃pXԂ
CString g_get_tmp_file();
// directory폜֐iɂt@CSāj
BOOL g_delete_directory(LPCTSTR dir_path);
// LOGFONT\̂Rs[܂B
void g_logfont_copy(LOGFONT *dst, LOGFONT *org);
// ^C][
CString g_get_tzoffset_from_tzname(CString name);
// cstringmarkň͂܂ꂽr
void g_strip_part(CString &buf, char *mark);
// ɔpJi܂܂Ă邩ǂm߂
BOOL g_is_hankana(unsigned char *buf);
// count char num from byte. this is for richeditview
int g_richedit_count_char(CString buf);

==> pochy-0.2-src.tar.gz: pochy-0.2-src/lib.h <==
//#include "liststackstruct.h"

void g_log(CString path, CString log);
BOOL g_rm_recursive(CString path);
BOOL g_cstring2file(/*CString& buf*/LPCTSTR buf, LPCTSTR filename);
BOOL g_file2cstring(LPCTSTR filename,CString& buf);
BOOL g_fcreate(LPCTSTR path);
BOOL g_connect_process(CStringArray &comline, CString &out1, CString &out2);
//int g_get_icon_index(const CString& csFileName);
// CStringesCStringArrayɊi[
void g_cstr2cstra(CString& cstr, CStringArray& cstra, LPCTSTR sep);
void g_cstr2cstra_ex(CString& cstr, CStringArray& cstra, LPCTSTR sep);
// CStringArrayɊesi[̂CStringɏo
void g_cstra2cstr(CStringArray& cstra, CString& cstr, int size);
// eLXgt@C̊esCStringArrayɓǂݍ
BOOL g_file2cstra(LPCTSTR path, CStringArray &cstra);
// CStringArrayɊesi[ꂽeLXgt@C֏o
BOOL g_cstra2file(LPCTSTR path, CStringArray &cstra);
// t@C̑傫Ԃ
long g_getfs(LPCTSTR path);
// t@CԍƂČƂA(num)ȏł܂݂Ȃŏ̔ԍԂ֐
int g_get_min_num(CString path);
// CStringArraystartsends܂ł擾
void g_cstra_getpart(CStringArray &org, CStringArray &dst, int start, int end);
// CStringArrayɊi[ĂCString̑TCY擾
int g_cstra_getsize(CStringArray& cstra);
// t@CtH_邩ȂmF
BOOL g_is_there(LPCTSTR path);
// 啶̊֌WȂCStringׁAvTRUEԂ
BOOL g_cstr_compare(LPCTSTR c, LPCTSTR d);
// <>̒̕Ԃ֐
CString g_ma(CString& to);
CString g_getfield(CString& body, LPCTSTR name);
CString g_gen_msgid(CString from);
void g_cstr_chop(CString &buf);
CString g_cstr_chop2(CString buf);
int g_cstr_rvs_find(CString org, LPCTSTR key, int start);
// e|[t@C쐬Ãt@Cւ̃pXԂ
CString g_get_tmp_file();
// directory폜֐iɂt@CSāj
BOOL g_delete_directory(LPCTSTR dir_path);
// LOGFONT\̂Rs[܂B
void g_logfont_copy(LOGFONT *dst, LOGFONT *org);
// ^C][
CString g_get_tzoffset_from_tzname(CString name);
// cstringmarkň͂܂ꂽr
void g_strip_part(CString &buf, char *mark);
// ɔpJi܂܂Ă邩ǂm߂
//BOOL g_is_hankana(unsigned char *buf);
// count char num from byte. this is for richeditview
int g_richedit_count_char(CString buf);
// ̊ȈՕ
CString g_simple_encode(const CString& in, const TCHAR seed = _T('\xb5'));
// ̊ȈՕ
CString g_simple_decode(const CString& in, const TCHAR seed = _T('\xb5'));
// clear all file in dir
void g_empty_directory(CString path);
// split address with ","
void g_split_address(CString address, CStringArray *array_address);
